/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/* gdome-events.h
 *
 * Copyright (C) 1999 Raph Levien <raph@acm.org>
 * Copyright (C) 2000 Mathieu Lacage <mathieu@gnu.org>
 * Copyright (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

/* ----- gdome.h ----- */
#ifndef GDOME_EVENTS_H
#define GDOME_EVENTS_H

#include "gdome.h"

typedef struct _GdomeEventVtab GdomeEventVtab;
typedef struct _GdomeEventListenerVtab GdomeEventListenerVtab;
typedef struct _GdomeMutationEventVtab GdomeMutationEventVtab;
typedef struct _GdomeUIEventVtab GdomeUIEventVtab;

#define GDOME_CAPTURING_PHASE 1
#define GDOME_AT_TARGET 2
#define GDOME_BUBBLING_PHASE 3

struct _GdomeEvent {
	const GdomeEventVtab *vtab;
};

struct _GdomeEventListener {
	const GdomeEventListenerVtab *vtab;
};

struct _GdomeMutationEvent {
	const GdomeMutationEventVtab *vtab;
};

struct _GdomeUIEvent {
	const GdomeUIEventVtab *vtab;
};

struct _GdomeEventVtab {
  void (*ref) (GdomeEvent *self, GdomeException *exc);
  void (*unref) (GdomeEvent *self, GdomeException *exc);
  void * (*query_interface) (GdomeEvent *self, const char *interface, GdomeException *exc);
  GdomeDOMString *(*type) (GdomeEvent *self, GdomeException *exc);
  GdomeNode *(*target) (GdomeEvent *self, GdomeException *exc);
  GdomeNode *(*currentTarget) (GdomeEvent *self, GdomeException *exc);
  unsigned short (*eventPhase) (GdomeEvent *self, GdomeException *exc);
  GdomeBoolean (*bubbles) (GdomeEvent *self, GdomeException *exc);
  GdomeBoolean (*cancelable) (GdomeEvent *self, GdomeException *exc);
  GdomeDOMTimeStamp (*timeStamp) (GdomeEvent *self, GdomeException *exc);
  void (*stopPropagation) (GdomeEvent *self, GdomeException *exc);
  void (*preventDefault) (GdomeEvent *self, GdomeException *exc);
  void (*initEvent) (GdomeEvent *self, GdomeDOMString *eventTypeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeException *exc);
};

struct _GdomeEventListenerVtab {
  void (*ref) (GdomeEventListener *self, GdomeException *exc);
  void (*unref) (GdomeEventListener *self, GdomeException *exc);
  void * (*query_interface) (GdomeEventListener *self, const char *interface, GdomeException *exc);
  void (*handleEvent) (GdomeEventListener *self, GdomeEvent *event, GdomeException *exc);
};

struct _GdomeMutationEventVtab {
  GdomeEventVtab super;
  GdomeNode *(*relatedNode) (GdomeMutationEvent *self, GdomeException *exc);
  GdomeDOMString *(*prevValue) (GdomeMutationEvent *self, GdomeException *exc);
  GdomeDOMString *(*newValue) (GdomeMutationEvent *self, GdomeException *exc);
  GdomeDOMString *(*attrName) (GdomeMutationEvent *self, GdomeException *exc);
  void (*initMutationEvent) (GdomeMutationEvent *self, GdomeDOMString *typeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeNode *relatedNodeArg, GdomeDOMString *prevValueArg, GdomeDOMString *newValueArg, GdomeDOMString *attrNameArg, GdomeException *exc);
};

struct _GdomeUIEventVtab {
  GdomeEventVtab super;
  long (*screenX) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_screenX) (GdomeUIEvent *self, long screenX, GdomeException *exc);
  long (*screenY) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_screenY) (GdomeUIEvent *self, long screenY, GdomeException *exc);
  long (*clientX) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_clientX) (GdomeUIEvent *self, long clientX, GdomeException *exc);
  long (*clientY) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_clientY) (GdomeUIEvent *self, long clientY, GdomeException *exc);
  GdomeBoolean (*altKey) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_altKey) (GdomeUIEvent *self, GdomeBoolean altKey, GdomeException *exc);
  GdomeBoolean (*ctrlKey) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_ctrlKey) (GdomeUIEvent *self, GdomeBoolean ctrlKey, GdomeException *exc);
  GdomeBoolean (*shiftKey) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_shiftKey) (GdomeUIEvent *self, GdomeBoolean shiftKey, GdomeException *exc);
  unsigned long (*keyCode) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_keyCode) (GdomeUIEvent *self, unsigned long keyCode, GdomeException *exc);
  unsigned long (*charCode) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_charCode) (GdomeUIEvent *self, unsigned long charCode, GdomeException *exc);
  unsigned short (*button) (GdomeUIEvent *self, GdomeException *exc);
  void (*set_button) (GdomeUIEvent *self, unsigned short button, GdomeException *exc);
};

void gdome_evnt_ref (GdomeEvent *self, GdomeException *exc);
void gdome_evnt_unref (GdomeEvent *self, GdomeException *exc);
void * gdome_evnt_query_interface (GdomeEvent *self, const char *interface, GdomeException *exc);
GdomeDOMString *gdome_evnt_type (GdomeEvent *self, GdomeException *exc);
GdomeNode *gdome_evnt_target (GdomeEvent *self, GdomeException *exc);
GdomeNode *gdome_evnt_currentTarget (GdomeEvent *self, GdomeException *exc);
unsigned short gdome_evnt_eventPhase (GdomeEvent *self, GdomeException *exc);
GdomeBoolean gdome_evnt_bubbles (GdomeEvent *self, GdomeException *exc);
GdomeBoolean gdome_evnt_cancelable (GdomeEvent *self, GdomeException *exc);
GdomeDOMTimeStamp gdome_evnt_timeStamp (GdomeEvent *self, GdomeException *exc);
void gdome_evnt_stopPropagation (GdomeEvent *self, GdomeException *exc);
void gdome_evnt_preventDefault (GdomeEvent *self, GdomeException *exc);
void gdome_evnt_initEvent (GdomeEvent *self, GdomeDOMString *eventTypeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeException *exc);



void gdome_evntl_ref (GdomeEventListener *self, GdomeException *exc);
void gdome_evntl_unref (GdomeEventListener *self, GdomeException *exc);
void * gdome_evntl_query_interface (GdomeEventListener *self, const char *interface, GdomeException *exc);
void gdome_evntl_handleEvent (GdomeEventListener *self, GdomeEvent *event, GdomeException *exc);



GdomeNode *gdome_mevnt_relatedNode (GdomeMutationEvent *self, GdomeException *exc);
GdomeDOMString *gdome_mevnt_prevValue (GdomeMutationEvent *self, GdomeException *exc);
GdomeDOMString *gdome_mevnt_newValue (GdomeMutationEvent *self, GdomeException *exc);
GdomeDOMString *gdome_mevnt_attrName (GdomeMutationEvent *self, GdomeException *exc);
void gdome_mevnt_initMutationEvent (GdomeMutationEvent *self, GdomeDOMString *typeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeNode *relatedNodeArg, GdomeDOMString *prevValueArg, GdomeDOMString *newValueArg, GdomeDOMString *attrNameArg, GdomeException *exc);
void gdome_mevnt_ref (GdomeMutationEvent *self, GdomeException *exc);
void gdome_mevnt_unref (GdomeMutationEvent *self, GdomeException *exc);
void * gdome_mevnt_query_interface (GdomeMutationEvent *self, const char *interface, GdomeException *exc);
GdomeDOMString *gdome_mevnt_type (GdomeMutationEvent *self, GdomeException *exc);
GdomeNode *gdome_mevnt_target (GdomeMutationEvent *self, GdomeException *exc);
GdomeNode *gdome_mevnt_currentTarget (GdomeMutationEvent *self, GdomeException *exc);
unsigned short gdome_mevnt_eventPhase (GdomeMutationEvent *self, GdomeException *exc);
GdomeBoolean gdome_mevnt_bubbles (GdomeMutationEvent *self, GdomeException *exc);
GdomeBoolean gdome_mevnt_cancelable (GdomeMutationEvent *self, GdomeException *exc);
GdomeDOMTimeStamp gdome_mevnt_timeStamp (GdomeMutationEvent *self, GdomeException *exc);
void gdome_mevnt_stopPropagation (GdomeMutationEvent *self, GdomeException *exc);
void gdome_mevnt_preventDefault (GdomeMutationEvent *self, GdomeException *exc);
void gdome_mevnt_initEvent (GdomeMutationEvent *self, GdomeDOMString *eventTypeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeException *exc);



long gdome_uievnt_screenX (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_screenX (GdomeUIEvent *self, long screenX, GdomeException *exc);
long gdome_uievnt_screenY (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_screenY (GdomeUIEvent *self, long screenY, GdomeException *exc);
long gdome_uievnt_clientX (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_clientX (GdomeUIEvent *self, long clientX, GdomeException *exc);
long gdome_uievnt_clientY (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_clientY (GdomeUIEvent *self, long clientY, GdomeException *exc);
GdomeBoolean gdome_uievnt_altKey (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_altKey (GdomeUIEvent *self, GdomeBoolean altKey, GdomeException *exc);
GdomeBoolean gdome_uievnt_ctrlKey (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_ctrlKey (GdomeUIEvent *self, GdomeBoolean ctrlKey, GdomeException *exc);
GdomeBoolean gdome_uievnt_shiftKey (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_shiftKey (GdomeUIEvent *self, GdomeBoolean shiftKey, GdomeException *exc);
unsigned long gdome_uievnt_keyCode (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_keyCode (GdomeUIEvent *self, unsigned long keyCode, GdomeException *exc);
unsigned long gdome_uievnt_charCode (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_charCode (GdomeUIEvent *self, unsigned long charCode, GdomeException *exc);
unsigned short gdome_uievnt_button (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_set_button (GdomeUIEvent *self, unsigned short button, GdomeException *exc);
void gdome_uievnt_ref (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_unref (GdomeUIEvent *self, GdomeException *exc);
void * gdome_uievnt_query_interface (GdomeUIEvent *self, const char *interface, GdomeException *exc);
GdomeDOMString *gdome_uievnt_type (GdomeUIEvent *self, GdomeException *exc);
GdomeNode *gdome_uievnt_target (GdomeUIEvent *self, GdomeException *exc);
GdomeNode *gdome_uievnt_currentTarget (GdomeUIEvent *self, GdomeException *exc);
unsigned short gdome_uievnt_eventPhase (GdomeUIEvent *self, GdomeException *exc);
GdomeBoolean gdome_uievnt_bubbles (GdomeUIEvent *self, GdomeException *exc);
GdomeBoolean gdome_uievnt_cancelable (GdomeUIEvent *self, GdomeException *exc);
GdomeDOMTimeStamp gdome_uievnt_timeStamp (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_stopPropagation (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_preventDefault (GdomeUIEvent *self, GdomeException *exc);
void gdome_uievnt_initEvent (GdomeUIEvent *self, GdomeDOMString *eventTypeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeException *exc);

#endif /* GDOME_EVENTS_H */
